@@ -20,19 +20,18 @@
 #'
 #' @examples
 #' \dontrun{
-#'    ui <- bitly_user_info(showRequestURL = TRUE)
+#' bitly_bearerToken("access token")
+#' ui <- bitly_user_info(showRequestURL = TRUE)
 #' }
 #'
-#' @import httr stringr lubridate
+#' @import httr2 stringr lubridate
 #' @export
 bitly_user_info <- function(showRequestURL = FALSE) {
   user_info_url <- "https://api-ssl.bitly.com/v4/user"
 
-  create_query <- list(access_token = bitly_auth_access())
+  df_user_info <- doBearerTokenRequest(verb = "GET", url = user_info_url, access_token = Sys.getenv("bitly_access_token"), showURL = showRequestURL)
 
-  df_user_info <- doRequest(verb = "GET", url = user_info_url, queryParameters = create_query, showURL = showRequestURL)
-
-  df_user_info_data <- data.frame(df_user_info, stringsAsFactors = FALSE)
+  df_user_info_data <- data.frame(df_user_info)
 
   # convert to readable format - use lubridate parse_date_time
   df_user_info_data$created <- ymd_hms(df_user_info_data$created, tz = "UTC")
@@ -60,6 +59,7 @@ bitly_user_info <- function(showRequestURL = FALSE) {
 #'
 #' @examples
 #' \dontrun{
+#' bitly_bearerToken("access token")
 #' # this applies only for "free" users
 #' uu <- bitly_update_user(name = "Malc")
 #'
@@ -67,23 +67,25 @@ bitly_user_info <- function(showRequestURL = FALSE) {
 #' uug <- bitly_update_user(name = "Malc", default_group_guid = "TestGroupID")
 #' }
 #'
-#' @import httr jsonlite lubridate
+#' @import httr2 jsonlite lubridate
 #'
 #' @export
 bitly_update_user <- function(default_group_guid = NULL, name = "", showRequestURL = FALSE) {
   user_info_url <- "https://api-ssl.bitly.com/v4/user"
+  access_token <- Sys.getenv("bitly_access_token")
 
   if (!is_bitly_user_premium_holder()) {
-    default_group_guid <- NULL
-    warning("Your account is not premium. Please report bugs in GitHub if this is not true.",
-            "We will now skip changing group guid.")
+    warning(
+      "Your account is not premium. Please report bugs in GitHub if this is not true. ",
+      "We will now skip changing group guid."
+    )
+    body <- list(name = name)
+  } else {
+    body <- list(name = name, default_group_guid = default_group_guid)
   }
 
-  query <- list(access_token = bitly_auth_access())
-  body <- list(name = name, default_group_guid = default_group_guid)
-
-  df_user_info <- doRequest("PATCH",
-    url = user_info_url, queryParameters = query,
+  df_user_info <- doBearerTokenRequest("PATCH",
+    url = user_info_url, access_token = access_token,
     patch_body = body, showURL = showRequestURL
   )
   df_user_info$created <- ymd_hms(df_user_info$created, tz = "UTC")
@@ -115,10 +117,13 @@ is_bitly_user_premium_holder <- function() {
 bitly_app_details <- function(client_id = "be03aead58f23bc1aee6e1d7b7a1d99d62f0ede8", showRequestURL = F) {
   oauth_app_details <- paste0("https://api-ssl.bitly.com/v4/apps/", client_id)
 
-  query <- list(access_token = bitly_auth_access(), client_id = client_id)
+  query <- list(client_id = client_id)
 
-  df_app_details <- doRequest("GET", url = oauth_app_details, queryParameters = query, showURL = showRequestURL)
-  df_app_details <- data.frame(df_app_details, stringsAsFactors = FALSE)
+  df_app_details <- doBearerTokenRequest("GET",
+    url = oauth_app_details, access_token = Sys.getenv("bitly_access_token"),
+    queryParameters = query, showURL = showRequestURL
+  )
+  df_app_details <- data.frame(df_app_details)
 
   return(df_app_details)
 }
@@ -128,15 +133,14 @@ bitly_app_details <- function(client_id = "be03aead58f23bc1aee6e1d7b7a1d99d62f0e
 #' @inheritParams bitly_user_info
 #' @return \code{data.frame} of end points and their rate limits by action
 #' @export
-
 bitly_rate_limits <- function(showRequestURL = F) {
-  query <- list(access_token = bitly_auth_access())
-  .url <- "https://api-ssl.bitly.com/v4/user/platform_limits"
+  platform_lmt <- "https://api-ssl.bitly.com/v4/user/platform_limits"
 
-  limits <- doRequest("GET",
-                      url = .url,
-                      queryParameters = query,
-                      showURL = showRequestURL)
+  limits <- doBearerTokenRequest("GET",
+    url = platform_lmt,
+    access_token = Sys.getenv("bitly_access_token"),
+    showURL = showRequestURL
+  )
 
   return(limits[[1]])
 }
