@@ -1,9 +1,12 @@
 library(testthat)
-library(httr)
+library(httr2)
 library(jsonlite)
 library(stringr)
+library(stringi)
 library(urlshorteneR)
+library(dotenv)
 
+dotenv::load_dot_env("r.secret")
 context("User Information")
 
 test_that("Return information about a user.", {
@@ -12,9 +15,8 @@ test_that("Return information about a user.", {
 })
 
 test_that("User data can be updated", {
-  uu <- bitly_update_user(name = "DOma")
-  expect_silent(uu)
-  expect_warning(bitly_update_user(name = "DOma", default_group_guid = "GroupIDUniqueRetsdat"))
+  expect_warning(bitly_update_user(name = "Doma"))
+  expect_warning(bitly_update_user(name = stri_rand_strings(1, 5, pattern = "[A-Za-z]"), default_group_guid = "GroupIDUniqueRetsdat"))
 })
 
 test_that("User has a free/premium account", {
@@ -26,5 +28,5 @@ context("OAUTH Application Details")
 
 test_that("Application provides some metadata", {
   ad <- bitly_app_details()
-  expect_equal(dim(ad)[[2]], 4)
+  expect_equal(dim(ad)[[2]], 5)
 })
